Module Name:    src
Committed By:   tsutsui
Date:           Sat Aug 22 17:38:06 UTC 2009

Modified Files:
        src/sys/dev/tc: bba.c cfb.c mfb.c px.c pxg.c sfb.c sfbplus.c stic.c
            tcds.c tfb.c xcfb.c

Log Message:
u_intNN_t -> uintNN_t


To generate a diff of this commit:
cvs rdiff -u -r1.36 -r1.37 src/sys/dev/tc/bba.c src/sys/dev/tc/px.c
cvs rdiff -u -r1.56 -r1.57 src/sys/dev/tc/cfb.c src/sys/dev/tc/tfb.c
cvs rdiff -u -r1.53 -r1.54 src/sys/dev/tc/mfb.c
cvs rdiff -u -r1.32 -r1.33 src/sys/dev/tc/pxg.c src/sys/dev/tc/sfbplus.c
cvs rdiff -u -r1.79 -r1.80 src/sys/dev/tc/sfb.c
cvs rdiff -u -r1.45 -r1.46 src/sys/dev/tc/stic.c
cvs rdiff -u -r1.24 -r1.25 src/sys/dev/tc/tcds.c
cvs rdiff -u -r1.50 -r1.51 src/sys/dev/tc/xcfb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/tc/bba.c
diff -u src/sys/dev/tc/bba.c:1.36 src/sys/dev/tc/bba.c:1.37
--- src/sys/dev/tc/bba.c:1.36	Tue May 12 14:47:04 2009
+++ src/sys/dev/tc/bba.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: bba.c,v 1.36 2009/05/12 14:47:04 cegger Exp $ */
+/* $NetBSD: bba.c,v 1.37 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
 /* maxine/alpha baseboard audio (bba) */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: bba.c,v 1.36 2009/05/12 14:47:04 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: bba.c,v 1.37 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -186,7 +186,7 @@
 
 static int	bba_intr(void *);
 static void	bba_reset(struct bba_softc *, int);
-static void	bba_codec_dwrite(struct am7930_softc *, int, u_int8_t);
+static void	bba_codec_dwrite(struct am7930_softc *, int, uint8_t);
 static uint8_t	bba_codec_dread(struct am7930_softc *, int);
 
 static int
@@ -513,7 +513,7 @@
 	struct bba_softc *sc;
 	struct bba_dma_state *d;
 	tc_addr_t phys, nphys;
-	u_int32_t ssr;
+	uint32_t ssr;
 	int state = 0;
 
 	DPRINTF(("bba_trigger_input: sc=%p start=%p end=%p blksize=%d intr=%p(%p)\n",
Index: src/sys/dev/tc/px.c
diff -u src/sys/dev/tc/px.c:1.36 src/sys/dev/tc/px.c:1.37
--- src/sys/dev/tc/px.c:1.36	Tue May 12 14:47:04 2009
+++ src/sys/dev/tc/px.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* 	$NetBSD: px.c,v 1.36 2009/05/12 14:47:04 cegger Exp $	*/
+/* 	$NetBSD: px.c,v 1.37 2009/08/22 17:38:06 tsutsui Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: px.c,v 1.36 2009/05/12 14:47:04 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: px.c,v 1.37 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -98,14 +98,14 @@
 
 static int	px_intr(void *);
 static uint32_t	*px_pbuf_get(struct stic_info *);
-static int	px_pbuf_post(struct stic_info *, u_int32_t *);
+static int	px_pbuf_post(struct stic_info *, uint32_t *);
 
 void	px_cnattach(tc_addr_t);
 
 struct px_softc {
 	device_t px_dev;
 	struct	stic_info *px_si;
-	volatile u_int32_t	*px_qpoll[PX_BUF_COUNT];
+	volatile uint32_t	*px_qpoll[PX_BUF_COUNT];
 };
 
 CFATTACH_DECL_NEW(px, sizeof(struct px_softc),
@@ -159,7 +159,7 @@
 		v = i * STIC_PACKET_SIZE +
 		    si->si_buf_phys + STIC_XCOMM_SIZE;
 		v = ((v & 0xffff8000) << 3) | (v & 0x7fff);
-		px->px_qpoll[i] = (volatile u_int32_t *)
+		px->px_qpoll[i] = (volatile uint32_t *)
 		    ((char *)si->si_slotbase + (v >> 9));
 	}
 
@@ -209,11 +209,11 @@
 		bpa = VM_PAGE_TO_PHYS(TAILQ_FIRST(&pglist));
 	}
 
-	si->si_vdac = (u_int32_t *)(kva + PX_VDAC_OFFSET);
-	si->si_vdac_reset = (u_int32_t *)(kva + PX_VDAC_RESET_OFFSET);
+	si->si_vdac = (uint32_t *)(kva + PX_VDAC_OFFSET);
+	si->si_vdac_reset = (uint32_t *)(kva + PX_VDAC_RESET_OFFSET);
 	si->si_stic = (volatile struct stic_regs *)(kva + PX_STIC_OFFSET);
-	si->si_stamp = (u_int32_t *)(kva + PX_STAMP_OFFSET);
-	si->si_buf = (u_int32_t *)TC_PHYS_TO_UNCACHED(bpa);
+	si->si_stamp = (uint32_t *)(kva + PX_STAMP_OFFSET);
+	si->si_buf = (uint32_t *)TC_PHYS_TO_UNCACHED(bpa);
 	si->si_buf_phys = bpa;
 	si->si_buf_size = PX_BUF_SIZE;
 	si->si_disptype = WSDISPLAY_TYPE_PX;
@@ -314,13 +314,13 @@
 
 	si->si_pbuf_select ^= STIC_PACKET_SIZE;
 	off = si->si_pbuf_select + STIC_XCOMM_SIZE;
-	return ((u_int32_t *)((char *)si->si_buf + off));
+	return ((uint32_t *)((char *)si->si_buf + off));
 }
 
 static int
-px_pbuf_post(struct stic_info *si, u_int32_t *buf)
+px_pbuf_post(struct stic_info *si, uint32_t *buf)
 {
-	volatile u_int32_t *poll, junk;
+	volatile uint32_t *poll, junk;
 	volatile struct stic_regs *sr;
 	u_long v;
 	int c;
@@ -330,7 +330,7 @@
 	/* Get address of poll register for this buffer. */
 	v = (u_long)STIC_KSEG_TO_PHYS(buf);
 	v = ((v & 0xffff8000) << 3) | (v & 0x7fff);
-	poll = (volatile u_int32_t *)((char *)si->si_slotbase + (v >> 9));
+	poll = (volatile uint32_t *)((char *)si->si_slotbase + (v >> 9));
 
 	/*
 	 * Read the poll register and make sure the stamp wants to accept

Index: src/sys/dev/tc/cfb.c
diff -u src/sys/dev/tc/cfb.c:1.56 src/sys/dev/tc/cfb.c:1.57
--- src/sys/dev/tc/cfb.c:1.56	Wed Dec 17 20:51:34 2008
+++ src/sys/dev/tc/cfb.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: cfb.c,v 1.56 2008/12/17 20:51:34 cegger Exp $ */
+/* $NetBSD: cfb.c,v 1.57 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cfb.c,v 1.56 2008/12/17 20:51:34 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cfb.c,v 1.57 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -68,18 +68,18 @@
  * adjacent each other in a word, i.e.,
  *	struct bt459triplet {
  * 		struct {
- *			u_int8_t u0;
- *			u_int8_t u1;
- *			u_int8_t u2;
+ *			uint8_t u0;
+ *			uint8_t u1;
+ *			uint8_t u2;
  *			unsigned :8;
  *		} bt_lo;
  *		...
  * Although CX has single Bt459, 32bit R/W can be done w/o any trouble.
  *	struct bt459reg {
- *		   u_int32_t	   bt_lo;
- *		   u_int32_t	   bt_hi;
- *		   u_int32_t	   bt_reg;
- *		   u_int32_t	   bt_cmap;
+ *		   uint32_t	   bt_lo;
+ *		   uint32_t	   bt_hi;
+ *		   uint32_t	   bt_reg;
+ *		   uint32_t	   bt_cmap;
  *	};
  */
 
@@ -90,7 +90,7 @@
 #define	bt_cmap 0xc
 
 #define	REGWRITE32(p,i,v) do {					\
-	*(volatile u_int32_t *)((p) + (i)) = (v); tc_wmb();	\
+	*(volatile uint32_t *)((p) + (i)) = (v); tc_wmb();	\
     } while (0)
 #define	VDACSELECT(p,r) do {					\
 	REGWRITE32(p, bt_lo, 0xff & (r));			\
@@ -99,9 +99,9 @@
 
 struct hwcmap256 {
 #define	CMAP_SIZE	256	/* 256 R/G/B entries */
-	u_int8_t r[CMAP_SIZE];
-	u_int8_t g[CMAP_SIZE];
-	u_int8_t b[CMAP_SIZE];
+	uint8_t r[CMAP_SIZE];
+	uint8_t g[CMAP_SIZE];
+	uint8_t b[CMAP_SIZE];
 };
 
 struct hwcursor64 {
@@ -110,9 +110,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 struct cfb_softc {
@@ -197,7 +197,7 @@
  *   3 2 1 0 3 2 1 0		0 0 1 1 2 2 3 3
  *   7 6 5 4 7 6 5 4		4 4 5 5 6 6 7 7
  */
-static const u_int8_t shuffle[256] = {
+static const uint8_t shuffle[256] = {
 	0x00, 0x40, 0x10, 0x50, 0x04, 0x44, 0x14, 0x54,
 	0x01, 0x41, 0x11, 0x51, 0x05, 0x45, 0x15, 0x55,
 	0x80, 0xc0, 0x90, 0xd0, 0x84, 0xc4, 0x94, 0xd4,
@@ -281,7 +281,7 @@
 	tc_intr_establish(parent, ta->ta_cookie, IPL_TTY, cfbintr, sc);
 
 	/* clear any pending interrupts */
-	*(volatile u_int8_t *)((char *)ri->ri_hw + CX_OFFSET_IREQ) = 0;
+	*(volatile uint8_t *)((char *)ri->ri_hw + CX_OFFSET_IREQ) = 0;
 
 	waa.console = console;
 	waa.scrdata = &cfb_screenlist;
@@ -295,7 +295,7 @@
 cfb_cmap_init(struct cfb_softc *sc)
 {
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	cm = &sc->sc_cmap;
@@ -504,7 +504,7 @@
 	int v;
 
 	base = (void *)sc->sc_ri->ri_hw;
-	*(u_int8_t *)(base + CX_OFFSET_IREQ) = 0;
+	*(uint8_t *)(base + CX_OFFSET_IREQ) = 0;
 	if (sc->sc_changed == 0)
 		return (1);
 
@@ -530,7 +530,7 @@
 		REGWRITE32(vdac, bt_reg, y >> 8);
 	}
 	if (v & WSDISPLAY_CURSOR_DOCMAP) {
-		u_int8_t *cp = sc->sc_cursor.cc_color;
+		uint8_t *cp = sc->sc_cursor.cc_color;
 
 		VDACSELECT(vdac, BT459_IREG_CCOLOR_2);
 		REGWRITE32(vdac, bt_reg, cp[1]);
@@ -542,12 +542,12 @@
 		REGWRITE32(vdac, bt_reg, cp[4]);
 	}
 	if (v & WSDISPLAY_CURSOR_DOSHAPE) {
-		u_int8_t *ip, *mp, img, msk;
-		u_int8_t u;
+		uint8_t *ip, *mp, img, msk;
+		uint8_t u;
 		int bcnt;
 
-		ip = (u_int8_t *)sc->sc_cursor.cc_image;
-		mp = (u_int8_t *)sc->sc_cursor.cc_mask;
+		ip = (uint8_t *)sc->sc_cursor.cc_image;
+		mp = (uint8_t *)sc->sc_cursor.cc_mask;
 
 		bcnt = 0;
 		VDACSELECT(vdac, BT459_IREG_CRAM_BASE+0);
@@ -595,7 +595,7 @@
 cfbhwinit(void *cfbbase)
 {
 	char *vdac = (char *)cfbbase + CX_BT459_OFFSET;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int i;
 
 	VDACSELECT(vdac, BT459_IREG_COMMAND_0);
Index: src/sys/dev/tc/mfb.c
diff -u src/sys/dev/tc/mfb.c:1.53 src/sys/dev/tc/mfb.c:1.54
--- src/sys/dev/tc/mfb.c:1.53	Wed Dec 17 20:51:35 2008
+++ src/sys/dev/tc/mfb.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: mfb.c,v 1.53 2008/12/17 20:51:35 cegger Exp $ */
+/* $NetBSD: mfb.c,v 1.54 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mfb.c,v 1.53 2008/12/17 20:51:35 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mfb.c,v 1.54 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -75,7 +75,7 @@
 #define	bt_ctl	0xc
 
 #define	REGWRITE32(p,i,v) do {					\
-	*(volatile u_int32_t *)((p) + (i)) = (v); tc_wmb();	\
+	*(volatile uint32_t *)((p) + (i)) = (v); tc_wmb();	\
     } while (0)
 
 #define	SELECT455(p,r) do {					\
@@ -98,9 +98,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 struct mfb_softc {
@@ -175,7 +175,7 @@
 static void set_curpos(struct mfb_softc *, struct wsdisplay_curpos *);
 
 /* bit order reverse */
-static const u_int8_t flip[256] = {
+static const uint8_t flip[256] = {
 	0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
 	0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
 	0x08, 0x88, 0x48, 0xc8, 0x28, 0xa8, 0x68, 0xe8,
@@ -259,9 +259,9 @@
 	tc_intr_establish(parent, ta->ta_cookie, IPL_TTY, mfbintr, sc);
 
 	/* clear any pending interrupts */
-	*(u_int8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET) = 0;
-	junk = *(u_int8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET);
-	*(u_int8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET) = 1;
+	*(uint8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET) = 0;
+	junk = *(uint8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET);
+	*(uint8_t *)((char *)ri->ri_hw + MX_IREQ_OFFSET) = 1;
 
 	waa.console = console;
 	waa.scrdata = &mfb_screenlist;
@@ -469,9 +469,9 @@
 	volatile register int junk;
 
 	base = (void *)sc->sc_ri->ri_hw;
-	junk = *(u_int8_t *)(base + MX_IREQ_OFFSET);
+	junk = *(uint8_t *)(base + MX_IREQ_OFFSET);
 #if 0
-	*(u_int8_t *)(base + MX_IREQ_OFFSET) = 0;
+	*(uint8_t *)(base + MX_IREQ_OFFSET) = 0;
 #endif
 	if (sc->sc_changed == 0)
 		return (1);
@@ -488,7 +488,7 @@
 	}
 	if (v & (WSDISPLAY_CURSOR_DOPOS | WSDISPLAY_CURSOR_DOHOT)) {
 		int x, y;
-		u_int32_t twin;
+		uint32_t twin;
 
 		x = sc->sc_cursor.cc_pos.x - sc->sc_cursor.cc_hot.x;
 		y = sc->sc_cursor.cc_pos.y - sc->sc_cursor.cc_hot.y;
@@ -503,7 +503,7 @@
 		REGWRITE32(curs, bt_ctl, TWIN_HI(y));
 	}
 	if (v & WSDISPLAY_CURSOR_DOCMAP) {
-		u_int8_t *cp = sc->sc_cursor.cc_color;
+		uint8_t *cp = sc->sc_cursor.cc_color;
 
 		SELECT455(vdac, 8);
 		REGWRITE32(vdac, bt_cmap, 0);
@@ -519,11 +519,11 @@
 		REGWRITE32(vdac, bt_ovly, 0);
 	}
 	if (v & WSDISPLAY_CURSOR_DOSHAPE) {
-		u_int8_t *ip, *mp, img, msk;
+		uint8_t *ip, *mp, img, msk;
 		int bcnt;
 
-		ip = (u_int8_t *)sc->sc_cursor.cc_image;
-		mp = (u_int8_t *)sc->sc_cursor.cc_mask;
+		ip = (uint8_t *)sc->sc_cursor.cc_image;
+		mp = (uint8_t *)sc->sc_cursor.cc_mask;
 		bcnt = 0;
 		SELECT431(curs, BT431_REG_CRAM_BASE);
 

Index: src/sys/dev/tc/pxg.c
diff -u src/sys/dev/tc/pxg.c:1.32 src/sys/dev/tc/pxg.c:1.33
--- src/sys/dev/tc/pxg.c:1.32	Tue May 12 14:47:04 2009
+++ src/sys/dev/tc/pxg.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* 	$NetBSD: pxg.c,v 1.32 2009/05/12 14:47:04 cegger Exp $	*/
+/* 	$NetBSD: pxg.c,v 1.33 2009/08/22 17:38:06 tsutsui Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pxg.c,v 1.32 2009/05/12 14:47:04 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pxg.c,v 1.33 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -87,7 +87,7 @@
 static void	pxg_init(struct stic_info *);
 static int	pxg_ioctl(struct stic_info *, u_long, void *, int, struct lwp *);
 static uint32_t	*pxg_pbuf_get(struct stic_info *);
-static int	pxg_pbuf_post(struct stic_info *, u_int32_t *);
+static int	pxg_pbuf_post(struct stic_info *, uint32_t *);
 static int	pxg_probe_planes(struct stic_info *);
 static int	pxg_probe_sram(struct stic_info *);
 
@@ -184,16 +184,16 @@
 static void
 pxg_init(struct stic_info *si)
 {
-	volatile u_int32_t *slot;
+	volatile uint32_t *slot;
 	char *kva;
 
 	kva = (void *)si->si_slotbase;
 
-	si->si_vdac = (u_int32_t *)(kva + PXG_VDAC_OFFSET);
-	si->si_vdac_reset = (u_int32_t *)(kva + PXG_VDAC_RESET_OFFSET);
+	si->si_vdac = (uint32_t *)(kva + PXG_VDAC_OFFSET);
+	si->si_vdac_reset = (uint32_t *)(kva + PXG_VDAC_RESET_OFFSET);
 	si->si_stic = (volatile struct stic_regs *)(kva + PXG_STIC_OFFSET);
-	si->si_stamp = (u_int32_t *)(kva + PXG_STAMP_OFFSET);
-	si->si_buf = (u_int32_t *)(kva + PXG_SRAM_OFFSET);
+	si->si_stamp = (uint32_t *)(kva + PXG_STAMP_OFFSET);
+	si->si_buf = (uint32_t *)(kva + PXG_SRAM_OFFSET);
 	si->si_buf_phys = STIC_KSEG_TO_PHYS(si->si_buf);
 	si->si_buf_size = pxg_probe_sram(si);
 	si->si_disptype = WSDISPLAY_TYPE_PXG;
@@ -204,7 +204,7 @@
 	si->si_ioctl = pxg_ioctl;
 
 	/* Disable the co-processor. */
-	slot = (volatile u_int32_t *)kva;
+	slot = (volatile uint32_t *)kva;
 	slot[PXG_I860_RESET_OFFSET >> 2] = 0;
 	tc_wmb();
 	slot[PXG_HOST_INTR_OFFSET >> 2] = 0;
@@ -224,9 +224,9 @@
 static int
 pxg_probe_sram(struct stic_info *si)
 {
-	volatile u_int32_t *a, *b;
+	volatile uint32_t *a, *b;
 
-	a = (volatile u_int32_t *)si->si_slotbase + (PXG_SRAM_OFFSET >> 2);
+	a = (volatile uint32_t *)si->si_slotbase + (PXG_SRAM_OFFSET >> 2);
 	b = a + (0x20000 >> 2);
 	*a = 4321;
 	*b = 1234;
@@ -237,7 +237,7 @@
 static int
 pxg_probe_planes(struct stic_info *si)
 {
-	volatile u_int32_t *vdac;
+	volatile uint32_t *vdac;
 	int id;
 
 	/*
@@ -272,15 +272,15 @@
 #ifdef notyet
 	struct stic_info *si;
 	volatile struct stic_regs *sr;
-	volatile u_int32_t *hi;
-	u_int32_t state;
+	volatile uint32_t *hi;
+	uint32_t state;
 	int it;
 
 	si = cookie;
 	sr = si->si_stic;
 	state = sr->sr_ipdvint;
-	hi = (volatile u_int32_t *)si->si_slotbase +
-	    (PXG_HOST_INTR_OFFSET / sizeof(u_int32_t));
+	hi = (volatile uint32_t *)si->si_slotbase +
+	    (PXG_HOST_INTR_OFFSET / sizeof(uint32_t));
 
 	/* Clear the interrupt condition */
 	it = hi[0] & 15;
@@ -309,13 +309,13 @@
 
 	si->si_pbuf_select ^= STIC_PACKET_SIZE;
 	off = si->si_pbuf_select + STIC_XCOMM_SIZE;
-	return ((u_int32_t *)((char *)si->si_buf + off));
+	return ((uint32_t *)((char *)si->si_buf + off));
 }
 
 static int
-pxg_pbuf_post(struct stic_info *si, u_int32_t *buf)
+pxg_pbuf_post(struct stic_info *si, uint32_t *buf)
 {
-	volatile u_int32_t *poll, junk;
+	volatile uint32_t *poll, junk;
 	volatile struct stic_regs *sr;
 	u_long v;
 	int c;
@@ -324,7 +324,7 @@
 
 	/* Get address of poll register for this buffer. */
 	v = ((u_long)buf - (u_long)si->si_buf) >> 9;
-	poll = (volatile u_int32_t *)((char *)si->si_slotbase + v);
+	poll = (volatile uint32_t *)((char *)si->si_slotbase + v);
 
 	/*
 	 * Read the poll register and make sure the stamp wants to accept
@@ -353,7 +353,7 @@
 	  struct lwp *l)
 {
 	struct stic_xinfo *sxi;
-	volatile u_int32_t *ptr = NULL;
+	volatile uint32_t *ptr = NULL;
 	int rv, s;
 
 	switch (cmd) {
@@ -364,7 +364,7 @@
 			return (rv);
 		if (si->si_dispmode != WSDISPLAYIO_MODE_MAPPED)
 			return (EBUSY);
-		ptr = (volatile u_int32_t *)si->si_slotbase;
+		ptr = (volatile uint32_t *)si->si_slotbase;
 		break;
 	}
 
@@ -410,11 +410,11 @@
 void
 pxg_load_fwseg(struct stic_info *si, struct pxg_fwseg *pfs)
 {
-	const u_int32_t *src;
-	u_int32_t *dst;
+	const uint32_t *src;
+	uint32_t *dst;
 	u_int left, i;
 
-	dst = (u_int32_t *)((void *)si->si_buf + pfs->pfs_addr);
+	dst = (uint32_t *)((void *)si->si_buf + pfs->pfs_addr);
 	src = pfs->pfs_data;
 
 	for (left = pfs->pfs_compsize; left != 0; left -= 4) {
Index: src/sys/dev/tc/sfbplus.c
diff -u src/sys/dev/tc/sfbplus.c:1.32 src/sys/dev/tc/sfbplus.c:1.33
--- src/sys/dev/tc/sfbplus.c:1.32	Sat Aug 22 17:36:12 2009
+++ src/sys/dev/tc/sfbplus.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: sfbplus.c,v 1.32 2009/08/22 17:36:12 tsutsui Exp $ */
+/* $NetBSD: sfbplus.c,v 1.33 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sfbplus.c,v 1.32 2009/08/22 17:36:12 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sfbplus.c,v 1.33 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -72,7 +72,7 @@
 #define bt_reg	2
 #define bt_cmap 3
 
-#define REG(base, index)	*((u_int32_t *)(base) + (index))
+#define REG(base, index)	*((uint32_t *)(base) + (index))
 #define SELECT(vdac, regno) do {			\
 	REG(vdac, bt_lo) = ((regno) & 0x00ff);		\
 	REG(vdac, bt_hi) = ((regno) & 0x0f00) >> 8;	\
@@ -81,9 +81,9 @@
 
 struct hwcmap256 {
 #define	CMAP_SIZE	256	/* 256 R/G/B entries */
-	u_int8_t r[CMAP_SIZE];
-	u_int8_t g[CMAP_SIZE];
-	u_int8_t b[CMAP_SIZE];
+	uint8_t r[CMAP_SIZE];
+	uint8_t g[CMAP_SIZE];
+	uint8_t b[CMAP_SIZE];
 };
 
 struct hwcursor64 {
@@ -92,9 +92,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 struct hwops {
@@ -102,8 +102,8 @@
 	void (*getlut)(void *, struct hwcmap256 *);
 	void (*visible)(void *, int);
 	void (*locate)(void *, struct hwcursor64 *);
-	void (*shape)(void *, struct wsdisplay_curpos *, u_int64_t *);
-	void (*color)(void *, u_int8_t *);
+	void (*shape)(void *, struct wsdisplay_curpos *, uint64_t *);
+	void (*color)(void *, uint8_t *);
 };
 
 struct sfbp_softc {
@@ -173,15 +173,15 @@
 static void bt459init(void *);
 static void bt459visible(void *, int);
 static void bt459locate(void *, struct hwcursor64 *);
-static void bt459shape(void *, struct wsdisplay_curpos *, u_int64_t *);
-static void bt459color(void *, u_int8_t *);
+static void bt459shape(void *, struct wsdisplay_curpos *, uint64_t *);
+static void bt459color(void *, uint8_t *);
 static void bt459setlut(void *, struct hwcmap256 *);
 
 static void sfbpvisible(void *, int);
 static void sfbplocate(void *, struct hwcursor64 *);
-static void sfbpshape(void *, struct wsdisplay_curpos *, u_int64_t *);
+static void sfbpshape(void *, struct wsdisplay_curpos *, uint64_t *);
 static void bt463init(void *);
-static void bt463color(void *, u_int8_t *);
+static void bt463color(void *, uint8_t *);
 static void noplut(void *, struct hwcmap256 *);
 
 /* EXPORT */ int sfbp_cnattach(tc_addr_t);
@@ -201,7 +201,7 @@
  *   3 2 1 0 3 2 1 0		0 0 1 1 2 2 3 3
  *   7 6 5 4 7 6 5 4		4 4 5 5 6 6 7 7
  */
-static const u_int8_t shuffle[256] = {
+static const uint8_t shuffle[256] = {
 	0x00, 0x40, 0x10, 0x50, 0x04, 0x44, 0x14, 0x54,
 	0x01, 0x41, 0x11, 0x51, 0x05, 0x45, 0x15, 0x55,
 	0x80, 0xc0, 0x90, 0xd0, 0x84, 0xc4, 0x94, 0xd4,
@@ -302,8 +302,8 @@
         tc_intr_establish(parent, ta->ta_cookie, IPL_TTY, sfbpintr, sc);
 
 	asic = (char *)ri->ri_hw + SFB_ASIC_OFFSET;
-	*(u_int32_t *)(asic + SFB_ASIC_CLEAR_INTR) = 0;
-	*(u_int32_t *)(asic + SFB_ASIC_ENABLE_INTR) = 1;
+	*(uint32_t *)(asic + SFB_ASIC_CLEAR_INTR) = 0;
+	*(uint32_t *)(asic + SFB_ASIC_ENABLE_INTR) = 1;
 
 	waa.console = console;
 	waa.scrdata = &sfb_screenlist;
@@ -317,7 +317,7 @@
 sfbp_cmap_init(struct sfbp_softc *sc)
 {
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	if (sc->sc_ri->ri_depth != 8)
@@ -340,9 +340,9 @@
 
 	base = ri->ri_hw;
 	asic = base + SFB_ASIC_OFFSET;
-	hsetup = *(u_int32_t *)(asic + SFB_ASIC_VIDEO_HSETUP);
-	vsetup = *(u_int32_t *)(asic + SFB_ASIC_VIDEO_VSETUP);
-	i = *(u_int32_t *)(asic + SFB_ASIC_DEEP);
+	hsetup = *(uint32_t *)(asic + SFB_ASIC_VIDEO_HSETUP);
+	vsetup = *(uint32_t *)(asic + SFB_ASIC_VIDEO_VSETUP);
+	i = *(uint32_t *)(asic + SFB_ASIC_DEEP);
 	depth = (i & 01) ? 32 : 8;
 
 	/*
@@ -350,18 +350,18 @@
 	 * - observed 804x600?, 644x480? values.
 	 */
 
-	*(u_int32_t *)(asic + SFB_ASIC_VIDEO_BASE) = vbase = 1;
+	*(uint32_t *)(asic + SFB_ASIC_VIDEO_BASE) = vbase = 1;
 	vbase *= (i & 0x20) ? 2048 : 4096;	/* VRAM chip size */
 	if (i & 1) vbase *= 4;			/* bytes per pixel */
 
-	*(u_int32_t *)(asic + SFB_ASIC_PLANEMASK) = ~0;
-	*(u_int32_t *)(asic + SFB_ASIC_PIXELMASK) = ~0;
-	*(u_int32_t *)(asic + SFB_ASIC_MODE) = 0;	/* MODE_SIMPLE */
-	*(u_int32_t *)(asic + SFB_ASIC_ROP) = 3;	/* ROP_COPY */
+	*(uint32_t *)(asic + SFB_ASIC_PLANEMASK) = ~0;
+	*(uint32_t *)(asic + SFB_ASIC_PIXELMASK) = ~0;
+	*(uint32_t *)(asic + SFB_ASIC_MODE) = 0;	/* MODE_SIMPLE */
+	*(uint32_t *)(asic + SFB_ASIC_ROP) = 3;		/* ROP_COPY */
 
 	/* initialize colormap and cursor hardware */
 	if (depth != 32) {
-		*(u_int32_t *)(asic + 0x180000) = 0;	/* Bt459 reset */
+		*(uint32_t *)(asic + 0x180000) = 0;	/* Bt459 reset */
 		bt459init(base + SFB_RAMDAC_OFFSET);
 	}
 	else {
@@ -572,13 +572,13 @@
 #define	cc (&sc->sc_cursor)
 	struct sfbp_softc *sc = arg;
 	char *base, *asic;
-	u_int32_t sisr;
+	uint32_t sisr;
 	int v;
 
 	base = sc->sc_ri->ri_hw;
 	asic = base + SFB_ASIC_OFFSET;
-	sisr = *((u_int32_t *)asic + TGA_REG_SISR);
-	*(u_int32_t *)(asic + SFB_ASIC_CLEAR_INTR) = 0;
+	sisr = *((uint32_t *)asic + TGA_REG_SISR);
+	*(uint32_t *)(asic + SFB_ASIC_CLEAR_INTR) = 0;
 
 	if (sc->sc_changed == 0)
 		goto done;
@@ -596,7 +596,7 @@
 		(*sc->sc_hwops.setlut)(base, &sc->sc_cmap);
 	sc->sc_changed = 0;
 done:
-	*((u_int32_t *)asic + TGA_REG_SISR) = sisr = 0x00000001; tc_wmb();
+	*((uint32_t *)asic + TGA_REG_SISR) = sisr = 0x00000001; tc_wmb();
 	return (1);
 #undef cc
 }
@@ -604,7 +604,7 @@
 static void
 bt459init(void *vdac)
 {
-	const u_int8_t *p;
+	const uint8_t *p;
 	int i;
 
 	SELECT(vdac, BT459_IREG_COMMAND_0);
@@ -875,12 +875,12 @@
 	y = cc->cc_pos.y - cc->cc_hot.y;
 
 	hw = (char *)hw + SFB_ASIC_OFFSET;
-	*((u_int32_t *)hw + TGA_REG_CXYR) = ((y & 0xfff) << 12) | (x & 0xfff);
+	*((uint32_t *)hw + TGA_REG_CXYR) = ((y & 0xfff) << 12) | (x & 0xfff);
 	tc_wmb();
 }
 
 static void
-bt459color(void *hw, u_int8_t *cp)
+bt459color(void *hw, uint8_t *cp)
 {
 
 	hw = (char *)hw + SFB_RAMDAC_OFFSET;
@@ -896,20 +896,20 @@
 }
 
 static void
-bt463color(void *hw, u_int8_t *cp)
+bt463color(void *hw, uint8_t *cp)
 {
 }
 
 static void
-bt459shape(void *hw, struct wsdisplay_curpos *size, u_int64_t *image)
+bt459shape(void *hw, struct wsdisplay_curpos *size, uint64_t *image)
 {
-	u_int8_t *ip, *mp, img, msk;
-	u_int8_t u;
+	uint8_t *ip, *mp, img, msk;
+	uint8_t u;
 	int bcnt;
 
 	hw = (char *)hw + SFB_RAMDAC_OFFSET;
-	ip = (u_int8_t *)image;
-	mp = (u_int8_t *)(image + CURSOR_MAX_SIZE);
+	ip = (uint8_t *)image;
+	mp = (uint8_t *)(image + CURSOR_MAX_SIZE);
 
 	bcnt = 0;
 	SELECT(hw, BT459_IREG_CRAM_BASE+0);
@@ -940,7 +940,7 @@
 }
 
 static void
-sfbpshape(void *hw, struct wsdisplay_curpos *size, u_int64_t *image)
+sfbpshape(void *hw, struct wsdisplay_curpos *size, uint64_t *image)
 {
 	/* XXX use SFBplus ASIC XXX */
 }
@@ -1012,35 +1012,35 @@
 #endif
 
 #define	SFBMODE(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_MODE) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_MODE) = (v))
 #define	SFBROP(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_ROP) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_ROP) = (v))
 #define	SFBPLANEMASK(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_PLANEMASK) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_PLANEMASK) = (v))
 #define	SFBPIXELMASK(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_PIXELMASK) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_PIXELMASK) = (v))
 #define	SFBADDRESS(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_ADDRESS) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_ADDRESS) = (v))
 #define	SFBSTART(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_START) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_START) = (v))
 #define	SFBPIXELSHIFT(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_PIXELSHIFT) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_PIXELSHIFT) = (v))
 #define	SFBFG(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_FG) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_FG) = (v))
 #define	SFBBG(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_BG) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_BG) = (v))
 #define	SFBBCONT(p, v) \
-		(*(u_int32_t *)(BUMP(p) + SFB_ASIC_BCONT) = (v))
+		(*(uint32_t *)(BUMP(p) + SFB_ASIC_BCONT) = (v))
 
 #define	SFBDATA(p, v) \
-		(*((u_int32_t *)BUMP(p) + TGA_REG_GDAR) = (v))
+		(*((uint32_t *)BUMP(p) + TGA_REG_GDAR) = (v))
 
 #define	SFBCOPY64BYTESDONE	8
 #define	SFBCOPY64BITS		64
 #define	SFBCOPY64SRC(p, v) \
-		(*((u_int32_t *)BUMP(p) + TGA_REG_GCSR) = (long)(v))
+		(*((uint32_t *)BUMP(p) + TGA_REG_GCSR) = (long)(v))
 #define	SFBCOPY64DST(p, v) \
-		(*((u_int32_t *)BUMP(p) + TGA_REG_GCDR) = (long)(v))
+		(*((uint32_t *)BUMP(p) + TGA_REG_GCDR) = (long)(v))
 
 /*
  * Actually write a string to the frame buffer.
@@ -1051,8 +1051,8 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, height, width, align, x, y;
-	u_int32_t lmask, rmask, glyph;
-	u_int8_t *g;
+	uint32_t lmask, rmask, glyph;
+	uint8_t *g;
 
 	x = col * ri->ri_font->fontwidth;
 	y = row * ri->ri_font->fontheight;
@@ -1075,18 +1075,18 @@
 	SFBFG(sfb, ri->ri_devcmap[(attr >> 24) & 15]);
 	SFBBG(sfb, ri->ri_devcmap[(attr >> 16) & 15]);
 	SFBROP(sfb, (3 << 8) | 3); /* ROP_COPY24 */
-	*((u_int32_t *)sfb + TGA_REG_GPXR_P) = lmask & rmask;
+	*((uint32_t *)sfb + TGA_REG_GPXR_P) = lmask & rmask;
 
 	/* XXX 2B stride fonts only XXX */
 	while (height > 0) {
-		glyph = *(u_int16_t *)g;		/* XXX */
-		*(u_int32_t *)p = glyph << align;
+		glyph = *(uint16_t *)g;			/* XXX */
+		*(uint32_t *)p = glyph << align;
 		p += scanspan;
 		g += 2;					/* XXX */
 		height--;
 	}
 	SFBMODE(sfb, MODE_SIMPLE);
-	*((u_int32_t *)sfb + TGA_REG_GPXR_P) = ~0;
+	*((uint32_t *)sfb + TGA_REG_GPXR_P) = ~0;
 }
 
 #undef	SFBSTIPPLEALL1
@@ -1105,7 +1105,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, startx, height, width, align, w, y;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	y = row * ri->ri_font->fontheight;
@@ -1128,7 +1128,7 @@
 	if (width <= SFBSTIPPLEBITS) {
 		lmask = lmask & rmask;
 		while (height > 0) {
-			*(u_int32_t *)p = lmask;
+			*(uint32_t *)p = lmask;
 			p += scanspan;
 			height--;
 		}
@@ -1136,17 +1136,17 @@
 	else {
 		char *q = p;
 		while (height > 0) {
-			*(u_int32_t *)p = lmask;
+			*(uint32_t *)p = lmask;
 			WRITE_MB();
 			width -= 2 * SFBSTIPPLEBITS;
 			while (width > 0) {
 				p += SFBSTIPPLEBYTESDONE;
-				*(u_int32_t *)p = SFBSTIPPLEALL1;
+				*(uint32_t *)p = SFBSTIPPLEALL1;
 				WRITE_MB();
 				width -= SFBSTIPPLEBITS;
 			}
 			p += SFBSTIPPLEBYTESDONE;
-			*(u_int32_t *)p = rmask;
+			*(uint32_t *)p = rmask;
 			WRITE_MB();
 
 			p = (q += scanspan);
@@ -1167,7 +1167,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, offset, srcy, height, width, align, w;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	height = ri->ri_font->fontheight * nrows;
@@ -1197,18 +1197,18 @@
 	else {
 		char *q = p;
 		while (height > 0) {
-			*(u_int32_t *)p = lmask;
-			*(u_int32_t *)(p + offset) = lmask;
+			*(uint32_t *)p = lmask;
+			*(uint32_t *)(p + offset) = lmask;
 			width -= 2 * SFBCOPYBITS;
 			while (width > 0) {
 				p += SFBCOPYBYTESDONE;
-				*(u_int32_t *)p = SFBCOPYALL1;
-				*(u_int32_t *)(p + offset) = SFBCOPYALL1;
+				*(uint32_t *)p = SFBCOPYALL1;
+				*(uint32_t *)(p + offset) = SFBCOPYALL1;
 				width -= SFBCOPYBITS;
 			}
 			p += SFBCOPYBYTESDONE;
-			*(u_int32_t *)p = rmask;
-			*(u_int32_t *)(p + offset) = rmask;
+			*(uint32_t *)p = rmask;
+			*(uint32_t *)(p + offset) = rmask;
 
 			p = (q += scanspan);
 			width = w + align;
@@ -1227,7 +1227,7 @@
 	struct rasops_info *ri = id;
 	void *sfb, *p, *q;
 	int scanspan, offset, srcy, height, width, w, align;
-	u_int32_t rmask, lmask;
+	uint32_t rmask, lmask;
 
 	scanspan = ri->ri_stride;
 	height = ri->ri_font->fontheight * nrows;
@@ -1266,14 +1266,14 @@
 				width -= SFBCOPY64BITS;
 			}
 			if (width >= SFBCOPYBITS) {
-				*(u_int32_t *)p = SFBCOPYALL1;
-				*(u_int32_t *)(p + offset) = SFBCOPYALL1;
+				*(uint32_t *)p = SFBCOPYALL1;
+				*(uint32_t *)(p + offset) = SFBCOPYALL1;
 				p += SFBCOPYBYTESDONE;
 				width -= SFBCOPYBITS;
 			}
 			if (width > 0) {
-				*(u_int32_t *)p = rmask;
-				*(u_int32_t *)(p + offset) = rmask;
+				*(uint32_t *)p = rmask;
+				*(uint32_t *)(p + offset) = rmask;
 			}
 
 			p = (q += scanspan);
@@ -1294,7 +1294,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, starty, height, width, align, w;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	starty = ri->ri_font->fontheight * startrow;
@@ -1319,17 +1319,17 @@
 	else {
 		char *q = p;
 		while (height > 0) {
-			*(u_int32_t *)p = lmask;
+			*(uint32_t *)p = lmask;
 			WRITE_MB();
 			width -= 2 * SFBSTIPPLEBITS;
 			while (width > 0) {
 				p += SFBSTIPPLEBYTESDONE;
-				*(u_int32_t *)p = SFBSTIPPLEALL1;
+				*(uint32_t *)p = SFBSTIPPLEALL1;
 				WRITE_MB();
 				width -= SFBSTIPPLEBITS;
 			}
 			p += SFBSTIPPLEBYTESDONE;
-			*(u_int32_t *)p = rmask;
+			*(uint32_t *)p = rmask;
 			WRITE_MB();
 
 			p = (q += scanspan);

Index: src/sys/dev/tc/sfb.c
diff -u src/sys/dev/tc/sfb.c:1.79 src/sys/dev/tc/sfb.c:1.80
--- src/sys/dev/tc/sfb.c:1.79	Thu Aug 20 12:55:26 2009
+++ src/sys/dev/tc/sfb.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: sfb.c,v 1.79 2009/08/20 12:55:26 tsutsui Exp $ */
+/* $NetBSD: sfb.c,v 1.80 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sfb.c,v 1.79 2009/08/20 12:55:26 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sfb.c,v 1.80 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -69,18 +69,18 @@
  * adjacent each other in a word, i.e.,
  *	struct bt459triplet {
  * 		struct {
- *			u_int8_t u0;
- *			u_int8_t u1;
- *			u_int8_t u2;
+ *			uint8_t u0;
+ *			uint8_t u1;
+ *			uint8_t u2;
  *			unsigned :8;
  *		} bt_lo;
  *
  * Although HX has single Bt459, 32bit R/W can be done w/o any trouble.
  *	struct bt459reg {
- *		   u_int32_t	   bt_lo;
- *		   u_int32_t	   bt_hi;
- *		   u_int32_t	   bt_reg;
- *		   u_int32_t	   bt_cmap;
+ *		   uint32_t	   bt_lo;
+ *		   uint32_t	   bt_hi;
+ *		   uint32_t	   bt_reg;
+ *		   uint32_t	   bt_cmap;
  *	};
  */
 
@@ -91,13 +91,13 @@
 #define	bt_cmap 0xc
 
 #define	REGWRITE32(p,i,v) do {					\
-	*(volatile u_int32_t *)((p) + (i)) = (v); tc_wmb();	\
+	*(volatile uint32_t *)((p) + (i)) = (v); tc_wmb();	\
     } while (/* CONSTCOND */ 0)
 #define	SFBWRITE32(p,i,v) do {					\
-	*(volatile u_int32_t *)((p) + (i)) = (v);		\
+	*(volatile uint32_t *)((p) + (i)) = (v);		\
     } while (/* CONSTCOND */ 0)
 #define	MEMWRITE32(p,v) do {					\
-	*(volatile u_int32_t *)(p) = (v);			\
+	*(volatile uint32_t *)(p) = (v);			\
     } while (/* CONSTCOND */ 0)
 
 #define	VDACSELECT(p,r) do {					\
@@ -107,9 +107,9 @@
 
 struct hwcmap256 {
 #define	CMAP_SIZE	256	/* 256 R/G/B entries */
-	u_int8_t r[CMAP_SIZE];
-	u_int8_t g[CMAP_SIZE];
-	u_int8_t b[CMAP_SIZE];
+	uint8_t r[CMAP_SIZE];
+	uint8_t g[CMAP_SIZE];
+	uint8_t b[CMAP_SIZE];
 };
 
 struct hwcursor64 {
@@ -118,9 +118,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 struct sfb_softc {
@@ -210,7 +210,7 @@
  *   3 2 1 0 3 2 1 0		0 0 1 1 2 2 3 3
  *   7 6 5 4 7 6 5 4		4 4 5 5 6 6 7 7
  */
-static const u_int8_t shuffle[256] = {
+static const uint8_t shuffle[256] = {
 	0x00, 0x40, 0x10, 0x50, 0x04, 0x44, 0x14, 0x54,
 	0x01, 0x41, 0x11, 0x51, 0x05, 0x45, 0x15, 0x55,
 	0x80, 0xc0, 0x90, 0xd0, 0x84, 0xc4, 0x94, 0xd4,
@@ -310,7 +310,7 @@
 sfb_cmap_init(struct sfb_softc *sc)
 {
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	cm = &sc->sc_cmap;
@@ -330,8 +330,8 @@
 
 	base = (void *)ri->ri_hw;
 	asic = base + SFB_ASIC_OFFSET;
-	hsetup = *(volatile u_int32_t *)(asic + SFB_ASIC_VIDEO_HSETUP);
-	vsetup = *(volatile u_int32_t *)(asic + SFB_ASIC_VIDEO_VSETUP);
+	hsetup = *(volatile uint32_t *)(asic + SFB_ASIC_VIDEO_HSETUP);
+	vsetup = *(volatile uint32_t *)(asic + SFB_ASIC_VIDEO_VSETUP);
 
 	vbase = 1;
 	SFBWRITE32(asic, SFB_ASIC_VIDEO_BASE, vbase);
@@ -582,7 +582,7 @@
 		REGWRITE32(vdac, bt_reg, y >> 8);
 	}
 	if (v & WSDISPLAY_CURSOR_DOCMAP) {
-		u_int8_t *cp = sc->sc_cursor.cc_color;
+		uint8_t *cp = sc->sc_cursor.cc_color;
 
 		VDACSELECT(vdac, BT459_IREG_CCOLOR_2);
 		REGWRITE32(vdac, bt_reg, cp[1]);
@@ -594,12 +594,12 @@
 		REGWRITE32(vdac, bt_reg, cp[4]);
 	}
 	if (v & WSDISPLAY_CURSOR_DOSHAPE) {
-		u_int8_t *ip, *mp, img, msk;
-		u_int8_t u;
+		uint8_t *ip, *mp, img, msk;
+		uint8_t u;
 		int bcnt;
 
-		ip = (u_int8_t *)sc->sc_cursor.cc_image;
-		mp = (u_int8_t *)sc->sc_cursor.cc_mask;
+		ip = (uint8_t *)sc->sc_cursor.cc_image;
+		mp = (uint8_t *)sc->sc_cursor.cc_mask;
 
 		bcnt = 0;
 		VDACSELECT(vdac, BT459_IREG_CRAM_BASE+0);
@@ -648,7 +648,7 @@
 sfbhwinit(void *base)
 {
 	char *vdac = (char *)base + SFB_RAMDAC_OFFSET;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int i;
 
 	VDACSELECT(vdac, BT459_IREG_COMMAND_0);
@@ -903,7 +903,7 @@
 {
 	char *sfb, *p;
 	int scanspan, height, width, align, x, y;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	x = ri->ri_ccol * ri->ri_font->fontwidth;
 	y = ri->ri_crow * ri->ri_font->fontheight;
@@ -943,8 +943,8 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, height, width, align, x, y;
-	u_int32_t lmask, rmask, glyph;
-	u_int8_t *g;
+	uint32_t lmask, rmask, glyph;
+	uint8_t *g;
 
 	x = col * ri->ri_font->fontwidth;
 	y = row * ri->ri_font->fontheight;
@@ -969,7 +969,7 @@
 	/* XXX 2B stride fonts only XXX */
 	lmask = lmask & rmask;
 	while (height > 0) {
-		glyph = *(u_int16_t *)g;		/* XXX */
+		glyph = *(uint16_t *)g;			/* XXX */
 		SFBPIXELMASK(sfb, lmask);
 		SFBADDRESS(sfb, (long)p);
 		SFBSTART(sfb, glyph << align);
@@ -998,7 +998,7 @@
 	struct rasops_info *ri = id;
 	void *sp, *dp, *basex, *sfb;
 	int scanspan, height, width, aligns, alignd, shift, w, y;
-	u_int32_t lmaskd, rmaskd;
+	uint32_t lmaskd, rmaskd;
 
 	scanspan = ri->ri_stride;
 	y = row * ri->ri_font->fontheight;
@@ -1125,7 +1125,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, startx, height, width, align, w, y;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	y = row * ri->ri_font->fontheight;
@@ -1184,7 +1184,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, offset, srcy, height, width, align, w;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	height = ri->ri_font->fontheight * nrows;
@@ -1243,7 +1243,7 @@
 	struct rasops_info *ri = id;
 	char *sfb, *p;
 	int scanspan, starty, height, width, align, w;
-	u_int32_t lmask, rmask;
+	uint32_t lmask, rmask;
 
 	scanspan = ri->ri_stride;
 	starty = ri->ri_font->fontheight * startrow;

Index: src/sys/dev/tc/stic.c
diff -u src/sys/dev/tc/stic.c:1.45 src/sys/dev/tc/stic.c:1.46
--- src/sys/dev/tc/stic.c:1.45	Wed Jul  9 13:19:33 2008
+++ src/sys/dev/tc/stic.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/*	$NetBSD: stic.c,v 1.45 2008/07/09 13:19:33 joerg Exp $	*/
+/*	$NetBSD: stic.c,v 1.46 2009/08/22 17:38:06 tsutsui Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -36,7 +36,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: stic.c,v 1.45 2008/07/09 13:19:33 joerg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: stic.c,v 1.46 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -93,19 +93,19 @@
  * adjacent each other in a word, i.e.,
  *	struct bt459triplet {
  * 		struct {
- *			u_int8_t u0;
- *			u_int8_t u1;
- *			u_int8_t u2;
+ *			uint8_t u0;
+ *			uint8_t u1;
+ *			uint8_t u2;
  *			unsigned :8;
  *		} bt_lo;
  *		struct {
  *
  * Although HX has single Bt459, 32bit R/W can be done w/o any trouble.
  *	struct bt459reg {
- *		   u_int32_t	   bt_lo;
- *		   u_int32_t	   bt_hi;
- *		   u_int32_t	   bt_reg;
- *		   u_int32_t	   bt_cmap;
+ *		   uint32_t	   bt_lo;
+ *		   uint32_t	   bt_hi;
+ *		   uint32_t	   bt_reg;
+ *		   uint32_t	   bt_cmap;
  *	};
  *
  */
@@ -116,7 +116,7 @@
 #define bt_reg	2
 #define bt_cmap 3
 
-#define REG(base, index)	*((volatile u_int32_t *)(base) + (index))
+#define REG(base, index)	*((volatile uint32_t *)(base) + (index))
 #define SELECT(vdac, regno) do {		\
 	REG(vdac, bt_lo) = DUPBYTE0(regno);	\
 	REG(vdac, bt_hi) = DUPBYTE1(regno);	\
@@ -161,7 +161,7 @@
 };
 
 /* Colormap for wscons, matching WSCOL_*. Upper 8 are high-intensity. */
-static const u_int8_t stic_cmap[16*3] = {
+static const uint8_t stic_cmap[16*3] = {
 	0x00, 0x00, 0x00, /* black */
 	0x7f, 0x00, 0x00, /* red */
 	0x00, 0x7f, 0x00, /* green */
@@ -188,7 +188,7 @@
  *   3 2 1 0 3 2 1 0		0 0 1 1 2 2 3 3
  *   7 6 5 4 7 6 5 4		4 4 5 5 6 6 7 7
  */
-static const u_int8_t shuffle[256] = {
+static const uint8_t shuffle[256] = {
 	0x00, 0x40, 0x10, 0x50, 0x04, 0x44, 0x14, 0x54,
 	0x01, 0x41, 0x11, 0x51, 0x05, 0x45, 0x15, 0x55,
 	0x80, 0xc0, 0x90, 0xd0, 0x84, 0xc4, 0x94, 0xd4,
@@ -267,7 +267,7 @@
 void
 stic_init(struct stic_info *si)
 {
-	volatile u_int32_t *vdac;
+	volatile uint32_t *vdac;
 	int i, cookie;
 
 	/* Reset the STIC & stamp(s). */
@@ -450,13 +450,13 @@
 static void
 stic_setup_vdac(struct stic_info *si)
 {
-	u_int8_t *ip, *mp;
+	uint8_t *ip, *mp;
 	int r, c, o, b, i, s;
 
 	s = spltty();
 
-	ip = (u_int8_t *)si->si_cursor.cc_image;
-	mp = (u_int8_t *)si->si_cursor.cc_mask;
+	ip = (uint8_t *)si->si_cursor.cc_image;
+	mp = (uint8_t *)si->si_cursor.cc_mask;
 	memset(ip, 0, sizeof(si->si_cursor.cc_image));
 	memset(mp, 0, sizeof(si->si_cursor.cc_mask));
 
@@ -500,7 +500,7 @@
 static void
 stic_clear_screen(struct stic_info *si)
 {
-	u_int32_t *pb;
+	uint32_t *pb;
 	int i;
 
 	/*
@@ -691,7 +691,7 @@
 	struct stic_screen *ss;
 	struct stic_info *si;
 	u_int r, c, nr, nc;
-	u_int16_t *p, *sp;
+	uint16_t *p, *sp;
 
 	ss = cookie;
 	si = ss->ss_si;
@@ -779,9 +779,9 @@
 {
 	struct stic_info *si;
 	struct stic_screen *ss;
-	u_int32_t *pb;
+	uint32_t *pb;
 	u_int i, linewidth;
-	u_int16_t *p;
+	uint16_t *p;
 
 	ss = cookie;
 	si = ss->ss_si;
@@ -789,7 +789,7 @@
 	if (ss->ss_backing != NULL) {
 		p = ss->ss_backing + row * si->si_consw + col;
 		for (i = num; i != 0; i--)
-			*p++ = (u_int16_t)attr;
+			*p++ = (uint16_t)attr;
 	}
 	if ((ss->ss_flags & SS_ACTIVE) == 0)
 		return;
@@ -821,15 +821,15 @@
 	struct stic_info *si;
 	struct stic_screen *ss;
 	u_int linewidth, i;
-	u_int32_t *pb;
+	uint32_t *pb;
 
 	ss = cookie;
 	si = ss->ss_si;
 
 	if (ss->ss_backing != NULL) {
-		pb = (u_int32_t *)(ss->ss_backing + row * si->si_consw);
+		pb = (uint32_t *)(ss->ss_backing + row * si->si_consw);
 		for (i = si->si_consw * num; i > 0; i -= 2)
-			*pb++ = (u_int32_t)attr;
+			*pb++ = (uint32_t)attr;
 	}
 	if ((ss->ss_flags & SS_ACTIVE) == 0)
 		return;
@@ -859,7 +859,7 @@
 {
 	struct stic_info *si;
 	struct stic_screen *ss;
-	u_int32_t *pb, *pbs;
+	uint32_t *pb, *pbs;
 	u_int num, inc, adj;
 
 	ss = cookie;
@@ -920,7 +920,7 @@
 	struct stic_info *si;
 	struct stic_screen *ss;
 	u_int height, updword;
-	u_int32_t *pb, *pbs;
+	uint32_t *pb, *pbs;
 
 	ss = cookie;
 	si = ss->ss_si;
@@ -1147,7 +1147,7 @@
 void
 stic_flush(struct stic_info *si)
 {
-	volatile u_int32_t *vdac;
+	volatile uint32_t *vdac;
 	int v;
 
 	if ((si->si_flags & SI_ALL_CHANGED) == 0)
@@ -1167,7 +1167,7 @@
 	}
 
 	if ((v & SI_CURCMAP_CHANGED) != 0) {
-		u_int8_t *cp;
+		uint8_t *cp;
 
 		cp = si->si_cursor.cc_color;
 
@@ -1181,12 +1181,12 @@
 	}
 
 	if ((v & SI_CURSHAPE_CHANGED) != 0) {
-		u_int8_t *ip, *mp, img, msk;
-		u_int8_t u;
+		uint8_t *ip, *mp, img, msk;
+		uint8_t u;
 		int bcnt;
 
-		ip = (u_int8_t *)si->si_cursor.cc_image;
-		mp = (u_int8_t *)si->si_cursor.cc_mask;
+		ip = (uint8_t *)si->si_cursor.cc_image;
+		mp = (uint8_t *)si->si_cursor.cc_mask;
 
 		bcnt = 0;
 		SELECT(vdac, BT459_IREG_CRAM_BASE);
@@ -1394,7 +1394,7 @@
 static void
 stic_set_hwcurpos(struct stic_info *si)
 {
-	volatile u_int32_t *vdac;
+	volatile uint32_t *vdac;
 	int x, y, s;
 
 	vdac = si->si_vdac;

Index: src/sys/dev/tc/tcds.c
diff -u src/sys/dev/tc/tcds.c:1.24 src/sys/dev/tc/tcds.c:1.25
--- src/sys/dev/tc/tcds.c:1.24	Wed Mar 18 16:00:20 2009
+++ src/sys/dev/tc/tcds.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: tcds.c,v 1.24 2009/03/18 16:00:20 cegger Exp $ */
+/* $NetBSD: tcds.c,v 1.25 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -58,7 +58,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: tcds.c,v 1.24 2009/03/18 16:00:20 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: tcds.c,v 1.25 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/kernel.h>
@@ -363,7 +363,7 @@
 void
 tcds_scsi_reset(struct tcds_slotconfig *sc)
 {
-	u_int32_t cir;
+	uint32_t cir;
 
 	tcds_dma_enable(sc, 0);
 	tcds_scsi_enable(sc, 0);
@@ -385,7 +385,7 @@
 void
 tcds_scsi_enable(struct tcds_slotconfig *sc, int on)
 {
-	u_int32_t imer;
+	uint32_t imer;
 
 	imer = bus_space_read_4(sc->sc_bst, sc->sc_bsh, TCDS_IMER);
 
@@ -400,7 +400,7 @@
 void
 tcds_dma_enable(struct tcds_slotconfig *sc, int on)
 {
-	u_int32_t cir;
+	uint32_t cir;
 
 	cir = bus_space_read_4(sc->sc_bst, sc->sc_bsh, TCDS_CIR);
 
@@ -416,7 +416,7 @@
 int
 tcds_scsi_isintr(struct tcds_slotconfig *sc, int clear)
 {
-	u_int32_t cir;
+	uint32_t cir;
 
 	cir = bus_space_read_4(sc->sc_bst, sc->sc_bsh, TCDS_CIR);
 
@@ -434,7 +434,7 @@
 int
 tcds_scsi_iserr(struct tcds_slotconfig *sc)
 {
-	u_int32_t cir;
+	uint32_t cir;
 
 	cir = bus_space_read_4(sc->sc_bst, sc->sc_bsh, TCDS_CIR);
 	return ((cir & sc->sc_errorbits) != 0);
@@ -444,7 +444,7 @@
 tcds_intr(void *arg)
 {
 	struct tcds_softc *sc = arg;
-	u_int32_t ir, ir0;
+	uint32_t ir, ir0;
 
 	/*
 	 * XXX
@@ -510,11 +510,11 @@
 tcds_params(struct tcds_softc *sc, int chip, int *idp, int *fastp)
 {
 	int id, fast;
-	u_int32_t ids;
+	uint32_t ids;
 
 #ifdef __alpha__
 	if (sc->sc_flags & TCDSF_BASEBOARD) {
-		extern u_int8_t dec_3000_scsiid[], dec_3000_scsifast[];
+		extern uint8_t dec_3000_scsiid[], dec_3000_scsifast[];
 
 		id = dec_3000_scsiid[chip];
 		fast = dec_3000_scsifast[chip];

Index: src/sys/dev/tc/xcfb.c
diff -u src/sys/dev/tc/xcfb.c:1.50 src/sys/dev/tc/xcfb.c:1.51
--- src/sys/dev/tc/xcfb.c:1.50	Tue May 12 14:47:04 2009
+++ src/sys/dev/tc/xcfb.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: xcfb.c,v 1.50 2009/05/12 14:47:04 cegger Exp $ */
+/* $NetBSD: xcfb.c,v 1.51 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: xcfb.c,v 1.50 2009/05/12 14:47:04 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: xcfb.c,v 1.51 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -58,9 +58,9 @@
 
 struct hwcmap256 {
 #define	CMAP_SIZE	256	/* 256 R/G/B entries */
-	u_int8_t r[CMAP_SIZE];
-	u_int8_t g[CMAP_SIZE];
-	u_int8_t b[CMAP_SIZE];
+	uint8_t r[CMAP_SIZE];
+	uint8_t g[CMAP_SIZE];
+	uint8_t b[CMAP_SIZE];
 };
 
 struct hwcursor64 {
@@ -69,9 +69,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;	/* not used by PMAG-DV */
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 #define	XCFB_FB_BASE	(XINE_PHYS_CFB_START + 0x2000000)
@@ -151,9 +151,9 @@
 static void ims332_set_curpos(struct xcfb_softc *);
 static void ims332_load_curcmap(struct xcfb_softc *);
 static void ims332_load_curshape(struct xcfb_softc *);
-static void ims332_write_reg(int, u_int32_t);
+static void ims332_write_reg(int, uint32_t);
 #if 0
-static u_int32_t ims332_read_reg(int);
+static uint32_t ims332_read_reg(int);
 #endif
 
 extern long ioasic_base;	/* XXX */
@@ -165,7 +165,7 @@
  *   3 2 1 0 3 2 1 0		3 3 2 2 1 1 0 0
  *   7 6 5 4 7 6 5 4		7 7 6 6 5 5 4 4
  */
-static const u_int8_t shuffle[256] = {
+static const uint8_t shuffle[256] = {
 	0x00, 0x01, 0x04, 0x05, 0x10, 0x11, 0x14, 0x15,
 	0x40, 0x41, 0x44, 0x45, 0x50, 0x51, 0x54, 0x55,
 	0x02, 0x03, 0x06, 0x07, 0x12, 0x13, 0x16, 0x17,
@@ -259,7 +259,7 @@
 xcfb_cmap_init(struct xcfb_softc *sc)
 {
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	cm = &sc->sc_cmap;
@@ -334,11 +334,11 @@
 static void
 xcfbhwinit(void *base)
 {
-	volatile u_int32_t *csr;
-	u_int32_t i;
-	const u_int8_t *p;
+	volatile uint32_t *csr;
+	uint32_t i;
+	const uint8_t *p;
 
-	csr = (volatile u_int32_t *)((char *)base + IOASIC_CSR);
+	csr = (volatile uint32_t *)((char *)base + IOASIC_CSR);
 	i = *csr;
 	i &= ~XINE_CSR_VDAC_ENABLE;
 	*csr = i;
@@ -369,7 +369,7 @@
 	/* build sane colormap */
 	p = rasops_cmap;
 	for (i = 0; i < CMAP_SIZE; i++, p += 3) {
-		u_int32_t bgr;
+		uint32_t bgr;
 
 		bgr = p[2] << 16 | p[1] << 8 | p[0];
 		ims332_write_reg(IMS332_REG_LUT_BASE + i, bgr);
@@ -518,9 +518,9 @@
 xcfbintr(void *v)
 {
 	struct xcfb_softc *sc = v;
-	u_int32_t *intr, i;
+	uint32_t *intr, i;
 
-	intr = (u_int32_t *)((char *)sc->sc_ri->ri_hw + IOASIC_INTR);
+	intr = (uint32_t *)((char *)sc->sc_ri->ri_hw + IOASIC_INTR);
 	i = *intr;
 	i &= ~XINE_INTR_VINT;
 	*intr = i;
@@ -677,7 +677,7 @@
 ims332_loadcmap(struct hwcmap256 *cm)
 {
 	int i;
-	u_int32_t rgb;
+	uint32_t rgb;
 
 	for (i = 0; i < CMAP_SIZE; i++) {
 		rgb = cm->b[i] << 16 | cm->g[i] << 8 | cm->r[i];
@@ -689,7 +689,7 @@
 ims332_set_curpos(struct xcfb_softc *sc)
 {
 	struct wsdisplay_curpos *curpos = &sc->sc_cursor.cc_pos;
-	u_int32_t pos;
+	uint32_t pos;
 	int s;
 
 	s = spltty();
@@ -701,8 +701,8 @@
 static void
 ims332_load_curcmap(struct xcfb_softc *sc)
 {
-	u_int8_t *cp = sc->sc_cursor.cc_color;
-	u_int32_t rgb;
+	uint8_t *cp = sc->sc_cursor.cc_color;
+	uint32_t rgb;
 
 	/* cursor background */
 	rgb = cp[5] << 16 | cp[3] << 8 | cp[1];
@@ -717,10 +717,10 @@
 ims332_load_curshape(struct xcfb_softc *sc)
 {
 	u_int i, img, msk, bits;
-	u_int8_t u, *ip, *mp;
+	uint8_t u, *ip, *mp;
 
-	ip = (u_int8_t *)sc->sc_cursor.cc_image;
-	mp = (u_int8_t *)sc->sc_cursor.cc_mask;
+	ip = (uint8_t *)sc->sc_cursor.cc_image;
+	mp = (uint8_t *)sc->sc_cursor.cc_mask;
 
 	i = 0;
 	/* 64 pixel scan line is consisted with 8 halfword cursor ram */
@@ -748,25 +748,25 @@
 }
 
 static void
-ims332_write_reg(int regno, u_int32_t val)
+ims332_write_reg(int regno, uint32_t val)
 {
 	void *high8 = (void *)(ioasic_base + IMS332_HIGH);
 	void *low16 = (void *)(ioasic_base + IMS332_WLOW + (regno << 4));
 
-	*(volatile u_int16_t *)high8 = (val & 0xff0000) >> 8;
-	*(volatile u_int16_t *)low16 = val;
+	*(volatile uint16_t *)high8 = (val & 0xff0000) >> 8;
+	*(volatile uint16_t *)low16 = val;
 }
 
 #if 0
-static u_int32_t
+static uint32_t
 ims332_read_reg(int regno)
 {
 	void *high8 = (void *)(ioasic_base + IMS332_HIGH);
 	void *low16 = (void *)(ioasic_base + IMS332_RLOW) + (regno << 4);
 	u_int v0, v1;
 
-	v1 = *(volatile u_int16_t *)high8;
-	v0 = *(volatile u_int16_t *)low16;
+	v1 = *(volatile uint16_t *)high8;
+	v0 = *(volatile uint16_t *)low16;
 	return (v1 & 0xff00) << 8 | v0;
 }
 #endif

Reply via email to
Index: src/sys/dev/tc/tfb.c
diff -u src/sys/dev/tc/tfb.c:1.56 src/sys/dev/tc/tfb.c:1.57
--- src/sys/dev/tc/tfb.c:1.56	Wed Dec 17 20:51:35 2008
+++ src/sys/dev/tc/tfb.c	Sat Aug 22 17:38:06 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: tfb.c,v 1.56 2008/12/17 20:51:35 cegger Exp $ */
+/* $NetBSD: tfb.c,v 1.57 2009/08/22 17:38:06 tsutsui Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: tfb.c,v 1.56 2008/12/17 20:51:35 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: tfb.c,v 1.57 2009/08/22 17:38:06 tsutsui Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -65,32 +65,32 @@
 
 /*
  * struct bt463reg {
- * 	u_int8_t	bt_lo;
+ * 	uint8_t		bt_lo;
  * 	unsigned : 24;
- * 	u_int8_t	bt_hi;
+ * 	uint8_t		bt_hi;
  * 	unsigned : 24;
- * 	u_int8_t	bt_reg;
+ * 	uint8_t		bt_reg;
  * 	unsigned : 24;
- * 	u_int8_t	bt_cmap;
+ * 	uint8_t		bt_cmap;
  * };
  *
  * N.B. a pair of Bt431s are located adjascently.
  * 	struct bt431twin {
  *		struct {
  *			u_int8_t u0;	for sprite mask
  *			u_int8_t u1;	for sprite image
  *			unsigned :16;
  *		} bt_lo;
  *		...
  *
  * struct bt431reg {
- * 	u_int16_t	bt_lo;
+ * 	uint16_t	bt_lo;
  * 	unsigned : 16;
- * 	u_int16_t	bt_hi;
+ * 	uint16_t	bt_hi;
  * 	unsigned : 16;
- * 	u_int16_t	bt_ram;
+ * 	uint16_t	bt_ram;
  * 	unsigned : 16;
- * 	u_int16_t	bt_ctl;
+ * 	uint16_t	bt_ctl;
  * };
  */
 
@@ -105,7 +105,7 @@
 #define	bt_ctl	0xc
 
 #define	REGWRITE32(p,i,v) do {					\
-	*(volatile u_int32_t *)((p) + (i)) = (v); tc_wmb();	\
+	*(volatile uint32_t *)((p) + (i)) = (v); tc_wmb();	\
     } while (0)
 
 #define	SELECT463(p,r) do {					\
@@ -124,9 +124,9 @@
 
 struct hwcmap256 {
 #define	CMAP_SIZE	256	/* R/G/B entries */
-	u_int8_t r[CMAP_SIZE];
-	u_int8_t g[CMAP_SIZE];
-	u_int8_t b[CMAP_SIZE];
+	uint8_t r[CMAP_SIZE];
+	uint8_t g[CMAP_SIZE];
+	uint8_t b[CMAP_SIZE];
 };
 
 struct hwcursor64 {
@@ -135,9 +135,9 @@
 	struct wsdisplay_curpos cc_size;
 	struct wsdisplay_curpos cc_magic;
 #define	CURSOR_MAX_SIZE	64
-	u_int8_t cc_color[6];
-	u_int64_t cc_image[CURSOR_MAX_SIZE];
-	u_int64_t cc_mask[CURSOR_MAX_SIZE];
+	uint8_t cc_color[6];
+	uint64_t cc_image[CURSOR_MAX_SIZE];
+	uint64_t cc_mask[CURSOR_MAX_SIZE];
 };
 
 struct tfb_softc {
@@ -229,7 +229,7 @@
 static void set_curpos(struct tfb_softc *, struct wsdisplay_curpos *);
 
 /* bit order reverse */
-static const u_int8_t flip[256] = {
+static const uint8_t flip[256] = {
 	0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
 	0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
 	0x08, 0x88, 0x48, 0xc8, 0x28, 0xa8, 0x68, 0xe8,
@@ -314,8 +314,8 @@
 
 	tc_intr_establish(parent, ta->ta_cookie, IPL_TTY, tfbintr, sc);
 
-	*(u_int8_t *)((char *)ri->ri_hw + TX_CONTROL) &= ~0x40;
-	*(u_int8_t *)((char *)ri->ri_hw + TX_CONTROL) |= 0x40;
+	*(uint8_t *)((char *)ri->ri_hw + TX_CONTROL) &= ~0x40;
+	*(uint8_t *)((char *)ri->ri_hw + TX_CONTROL) |= 0x40;
 
 	waa.console = console;
 	waa.scrdata = &tfb_screenlist;
@@ -377,7 +377,7 @@
 tfb_cmap_init(struct tfb_softc *sc)
 {
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	cm = &sc->sc_cmap;
@@ -542,7 +542,7 @@
 	int v;
 
 	base = (void *)sc->sc_ri->ri_hw;
-	*(u_int8_t *)(base + TX_CONTROL) &= ~0x40;
+	*(uint8_t *)(base + TX_CONTROL) &= ~0x40;
 	if (sc->sc_changed == 0)
 		goto done;
 
@@ -558,7 +558,7 @@
 	}
 	if (v & (WSDISPLAY_CURSOR_DOPOS | WSDISPLAY_CURSOR_DOHOT)) {
 		int x, y;
-		u_int32_t twin;
+		uint32_t twin;
 
 		x = sc->sc_cursor.cc_pos.x - sc->sc_cursor.cc_hot.x;
 		y = sc->sc_cursor.cc_pos.y - sc->sc_cursor.cc_hot.y;
@@ -573,7 +573,7 @@
 		REGWRITE32(curs, bt_ctl, TWIN_HI(y));
 	}
 	if (v & WSDISPLAY_CURSOR_DOCMAP) {
-		u_int8_t *cp = sc->sc_cursor.cc_color;
+		uint8_t *cp = sc->sc_cursor.cc_color;
 
 		SELECT463(vdac, BT463_IREG_CURSOR_COLOR_0);
 		REGWRITE32(vdac, bt_reg, cp[1]);
@@ -593,11 +593,11 @@
 		REGWRITE32(vdac, bt_reg, cp[5]);
 	}
 	if (v & WSDISPLAY_CURSOR_DOSHAPE) {
-		u_int8_t *ip, *mp, img, msk;
+		uint8_t *ip, *mp, img, msk;
 		int bcnt;
 
-		ip = (u_int8_t *)sc->sc_cursor.cc_image;
-		mp = (u_int8_t *)sc->sc_cursor.cc_mask;
+		ip = (uint8_t *)sc->sc_cursor.cc_image;
+		mp = (uint8_t *)sc->sc_cursor.cc_mask;
 		bcnt = 0;
 		SELECT431(curs, BT431_REG_CRAM_BASE);
 
@@ -636,8 +636,8 @@
 	}
 	sc->sc_changed = 0;
 done:
-	*(u_int8_t *)(base + TX_CONTROL) &= ~0x40;	/* !? Eeeh !? */
-	*(u_int8_t *)(base + TX_CONTROL) |= 0x40;
+	*(uint8_t *)(base + TX_CONTROL) &= ~0x40;	/* !? Eeeh !? */
+	*(uint8_t *)(base + TX_CONTROL) |= 0x40;
 	return (1);
 }
 
@@ -645,7 +645,7 @@
 tfbhwinit(void *tfbbase)
 {
 	char *vdac, *curs;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int i;
 
 	vdac = (char *)tfbbase + TX_BT463_OFFSET;
@@ -667,7 +667,7 @@
 
 #if 0 /* XXX ULTRIX does initialize 16 entry window type here XXX */
   {
-	static u_int32_t windowtype[BT463_IREG_WINDOW_TYPE_TABLE] = {
+	static uint32_t windowtype[BT463_IREG_WINDOW_TYPE_TABLE] = {
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	};
 
@@ -65,32 +65,32 @@
  * 	struct bt431twin {
  *		struct {
- *			u_int8_t u0;	for sprite mask
- *			u_int8_t u1;	for sprite image
+ *			uint8_t u0;	for sprite mask
+ *			uint8_t u1;	for sprite image
  *			unsigned :16;
  *		} bt_lo;
